@@ -10,9 +10,13 @@ Currently only:
 from ormar.decorators.property_field import property_field
 from ormar.decorators.signals import (
     post_delete,
+    post_relation_add,
+    post_relation_remove,
     post_save,
     post_update,
     pre_delete,
+    pre_relation_add,
+    pre_relation_remove,
     pre_save,
     pre_update,
 )
@@ -25,4 +29,8 @@ __all__ = [
     "pre_delete",
     "pre_save",
     "pre_update",
+    "post_relation_remove",
+    "post_relation_add",
+    "pre_relation_remove",
+    "pre_relation_add",
 ]
